package main

import (
	"dubbo.apache.org/dubbo-go/v3/config"
	_ "dubbo.apache.org/dubbo-go/v3/filter/tps/strategy"
	_ "dubbo.apache.org/dubbo-go/v3/imports"
	exhibitionConfig "exhibition-register/config"
	"exhibition-register/internal/controller"
	_ "exhibition-register/internal/handler"
	"exhibition-register/pkg/app"
	common "exhibition-register/pkg/init"
	"exhibition-register/pkg/msg"
	"exhibition-register/pkg/tracing"
	"github.com/bwmarrin/snowflake"
	"github.com/getsentry/sentry-go"
	"go.uber.org/zap"
	"gorm.io/gorm"
	"os"
	"time"
)

func NewApp(Lg *zap.Logger, JaegerTracer *tracing.JaegerProvider, SfNode *snowflake.Node, ExhibitionRegister *gorm.DB) *app.App {
	return &app.App{
		Lg:                 Lg,
		JaegerTracer:       JaegerTracer,
		SfNode:             SfNode,
		ExhibitionRegister: ExhibitionRegister,
	}
}

func main() {
	// 启动错误追踪日志
	errs := sentry.Init(sentry.ClientOptions{
		Dsn:              "https://3022195bbac2a3721fce115622c271b3@sentry.szjixun.cn/29",
		TracesSampleRate: 1.0,
		Environment:      os.Getenv(msg.MODE_ENV),
	})
	if errs != nil {
		zap.L().Error("InitSentry", zap.Error(errs))
	}
	defer sentry.Flush(2 * time.Second)

	var err error
	exhibitionConfig.GetOptions()
	app.ModuleClients, err = InitApp()
	if err != nil {
		panic(err)
	}

	//l, err := net.Listen("tcp", ":8883")
	//if err != nil {
	//	fmt.Printf("failed to listen: %v", err)
	//	return
	//}
	//
	//s := grpc.NewServer()                               // 创建gRPC服务器
	//dci.RegisterDciServer(s, &controller.DciProvider{}) // 在gRPC服务端注册服务
	// 启动服务
	//err = s.Serve(l)
	//注册服务
	config.SetProviderService(&controller.ExhibitionProvider{})
	common.Init()
	if err = config.Load(); err != nil {
		panic(err)
	}
	select {}
}
